@@ -1264,17 +1264,30 @@ static gboolean
 panel_check_network_manager_version (CcNetworkPanel *panel)
 {
         const gchar *version;
+        gchar **split = NULL;
+        guint major = 0;
+        guint micro = 0;
+        guint minor = 0;
         gboolean ret = TRUE;
 
         /* parse running version */
         version = nm_client_get_version (panel->priv->client);
-        if (version == NULL) {
+        if (version != NULL) {
+                split = g_strsplit (version, ".", -1);
+                major = atoi (split[0]);
+                minor = atoi (split[1]);
+                micro = atoi (split[2]);
+        }
+
+        /* is it too new or old */
+        if (major > 0 || major > 9 || (minor <= 8 && micro < 992)) {
                 ret = FALSE;
 
                 /* do modal dialog in idle so we don't block startup */
                 panel->priv->nm_warning_idle = g_idle_add ((GSourceFunc)display_version_warning_idle, panel);
         }
 
+        g_strfreev (split);
         return ret;
 }
 
@@ -1321,8 +1334,8 @@ on_toplevel_map (GtkWidget      *widget,
 {
         gboolean ret;
 
-        /* is the user compiling against a new version, but not running
-         * the daemon? */
+        /* is the user compiling against a new version, but running an
+         * old daemon version? */
         ret = panel_check_network_manager_version (panel);
         if (ret) {
                 manager_running (panel->priv->client, NULL, panel);
