@@ -350,10 +350,10 @@ validate (NetConnectionEditor *editor)
                 if (!ce_page_validate (CE_PAGE (l->data), editor->connection, &error)) {
                         valid = FALSE;
                         if (error) {
-                                g_debug ("Invalid setting %s: %s", ce_page_get_title (CE_PAGE (l->data)), error->message);
+                                g_warning ("Invalid setting %s: %s", ce_page_get_title (CE_PAGE (l->data)), error->message);
                                 g_error_free (error);
                         } else {
-                                g_debug ("Invalid setting %s", ce_page_get_title (CE_PAGE (l->data)));
+                                g_warning ("Invalid setting %s", ce_page_get_title (CE_PAGE (l->data)));
                         }
                 }
         }
@@ -594,9 +594,6 @@ typedef struct {
 static const NetConnectionType connection_types[] = {
         { N_("VPN"), nm_setting_vpn_get_type },
         { N_("Bond"), nm_setting_bond_get_type },
-#ifdef HAVE_NM_UNSTABLE
-        { "Team", nm_setting_team_get_type },
-#endif /* NM_UNSTABLE */
         { N_("Bridge"), nm_setting_bridge_get_type },
         { N_("VLAN"), nm_setting_vlan_get_type }
 };
@@ -782,8 +779,8 @@ select_vpn_type (NetConnectionEditor *editor, GtkListBox *list)
                 row = gtk_list_box_row_new ();
 
                 row_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-                gtk_widget_set_margin_left (row_box, 12);
-                gtk_widget_set_margin_right (row_box, 12);
+                gtk_widget_set_margin_start (row_box, 12);
+                gtk_widget_set_margin_end (row_box, 12);
                 gtk_widget_set_margin_top (row_box, 12);
                 gtk_widget_set_margin_bottom (row_box, 12);
 
@@ -813,8 +810,8 @@ select_vpn_type (NetConnectionEditor *editor, GtkListBox *list)
         row = gtk_list_box_row_new ();
 
         row_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-        gtk_widget_set_margin_left (row_box, 12);
-        gtk_widget_set_margin_right (row_box, 12);
+        gtk_widget_set_margin_start (row_box, 12);
+        gtk_widget_set_margin_end (row_box, 12);
         gtk_widget_set_margin_top (row_box, 12);
         gtk_widget_set_margin_bottom (row_box, 12);
 
@@ -873,8 +870,8 @@ net_connection_editor_add_connection (NetConnectionEditor *editor)
                 row_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
                 label = gtk_label_new (_(connection_types[i].name));
                 gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-                gtk_widget_set_margin_left (label, 12);
-                gtk_widget_set_margin_right (label, 12);
+                gtk_widget_set_margin_start (label, 12);
+                gtk_widget_set_margin_end (label, 12);
                 gtk_widget_set_margin_top (label, 12);
                 gtk_widget_set_margin_bottom (label, 12);
                 gtk_box_pack_start (GTK_BOX (row_box), label, FALSE, TRUE, 0);
